#
# spec file for package guile-git
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           guile-git
Version:        0.5.2
Release:        1.7
Summary:        Guile bindings of libgit2
License:        GPL-3.0-or-later
Group:          Development/Libraries/Other
URL:            https://gitlab.com/guile-git/guile-git
Source0:        https://gitlab.com/guile-git/guile-git/-/archive/v%{version}/%{name}-v%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  guile-bytestructures
BuildRequires:  guile-devel
BuildRequires:  libgit2-devel
BuildRequires:  pkg-config
BuildRequires:  texinfo
Requires:       guile
Requires:       guile-bytestructures
Requires:       libgit2-devel
Requires(pre):  %{install_info_prereq}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides Guile bindings to libgit2,
a library manipulate repositories of the Git version control system.

%prep
%setup -q -n %{name}-v%{version}
autoreconf -vif

%build
%configure
# build non-parallel for reproducible build results (boo#1170378)
make

%install
%make_install

%post
%install_info --info-dir=%{_infodir} %{_infodir}/guile-git.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/guile-git.info.gz

%files
%defattr(-,root,root)
%license COPYING
%doc NEWS README.md
%{_libdir}/guile/*/site-ccache/git*
%{_datadir}/guile/site/*/git*
%{_infodir}/guile-git.info.gz

%changelog
* Sun Dec 18 2022 Dirk Müller <dmueller@suse.com>
- update to 0.5.2:
  * Fix crash when fetching multiple sub-modules
    This bug was reported at <https://issues.guix.gnu.org/48855>.  It could
    lead to crashes via SIGSEGV or SIGILL while fetching multiple
    sub-modules in a row.
* Wed Jul  7 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- build non-parallel for reproducible build results (boo#1170378)
* Wed May 12 2021 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to version 0.5.1:
  * Fix crash when using ‘config-foreach’ or ‘config-fold’
  * commit: Prevent dangling repository references
  * New diff bindings in (git diff)
  * New configuration parsing support in (git config)
  * New tag procedures: ‘tag-fold’, ‘tag-foreach’
  * New tree procedures: ‘tree-entry-byname’, ‘tree-entry-type’
  * New remote procedures: ‘remote-url’, ‘remote-set-url!’
  * Submodule interface changes
* Fri Nov  6 2020 Jonathan Brielmaier <jbrielmaier@opensuse.org>
- Update to version 0.4.0:
  * Support for HTTP and HTTPS proxies
  * Support for progress report
  * Fix typo that made repository-index and repository-refdb unusable
* Tue Jan 14 2020 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 0.3.0:
  * Support for Guile 3.0
  * New modules (git signature), (git describe), (git blob)
  * Add new (git tag) procedures
  * Add accessor and setter for the download tags of ~fetch-options~
  * Add ~CREDTYPE-*~ variables
  * Add ssh authentication support
  * ~repository-state~ return a symbols instead of an int
  * Rename ~foo-init-options~ procedures to be more idiomatic
- Remove patch:
  * support-guile-3.0.patch: Included in release
* Mon Jan 13 2020 Jonathan Brielmaier <jbrielmaier@suse.de>
- Make files section compatible with Guile 3.0
- Add patch:
  * support-guile-3.0.patch: Adds support for Guile 3.0
* Wed Jan 30 2019 jbrielmaier@suse.de
- upate to 0.2.0:
  * New Functionality
  * * Add (git submodule) module
  * Bug fixes
  * * Fix experience in REPL
  * * Correctly export ~repository-working-directory~
  For more details see /usr/share/doc/packages/guile-git/NEWS
- package NEWS file
* Tue Dec 11 2018 jbrielmaier@suse.de
- add libgit2-devel as run time dependency to avoid
  "/usr/lib64/libgit2", message: "file not found" error
* Mon Sep 17 2018 <jbrielmaier@suse.de>
- remove needless _service and tar file
* Fri Sep 14 2018 jbrielmaier@suse.de
- bump to 0.1.0:
  - support remote-ls
  - support repository-close
  - small fixes
- switch from git service to release tarball
- order build requires alphabetical
- install info files
- COPYING now as license
* Sat Mar 10 2018 jengelh@inai.de
- Update description.
* Fri Mar  9 2018 sleep_walker@opensuse.org
- make package compatibile with guile-2.0+
- make _service localonly
* Tue Jan 23 2018 jbrielmaier@suse.com
- Initial version built from commit 951a32c
